import { Component, OnInit, Input, OnDestroy } from '@angular/core';
import { ToolbarHelpers } from './toolbar.helpers';
import { Title } from '@angular/platform-browser';
import { Direction } from '@angular/cdk/bidi';

import { ISubscription } from 'rxjs/Subscription';

import { LocaleService, TranslationService } from 'angular-l10n';

@Component({
  selector: 'of-header',
  templateUrl: './header.component.html',
  styleUrls: ['./header.component.scss']
})
export class HeaderComponent implements OnInit, OnDestroy {

  countryMenuItems: any[] = [
    { text: 'United States', language: 'en', country: 'US', currency: 'USD', numberingSystem: 'latn' },
    { text: 'Korea', language: 'kr', country: 'KR', currency: 'KRW', numberingSystem: 'latn' }
];

  @Input() sidenav;
  @Input() sidebar;
  @Input() drawer;
  @Input() matDrawerShow;

  searchOpen = false;
  toolbarHelpers = ToolbarHelpers;

  dir: Direction;

  subscription: ISubscription;

  constructor(public locale: LocaleService, public translation: TranslationService, public title: Title) { }

  ngOnInit() {
    this.subscription = this.translation.translationChanged().subscribe(
      () => { this.title.setTitle(this.translation.translate('App.Title')); }
    );

    // Initializes direction.
    // this.dir = this.getLanguageDirection();
  }

  ngOnDestroy(): void {
    this.subscription.unsubscribe();
  }

  // getLanguageDirection(language?: string): Direction {
  //     return this.locale.getLanguageDirection(language) as Direction;
  // }

  get currentCountry(): string {
    return this.locale.getCurrentCountry();
  }

  get currentNumberingSystem(): string {
    return this.locale.getCurrentNumberingSystem();
  }

  selectLocale(language: string, country: string, currency: string, numberingSystem: string): void {
      this.locale.setDefaultLocale(language, country, '', numberingSystem);
      this.locale.setCurrentCurrency(currency);
  }
}
