import {
  RPCClientCodec,
  RPCClientResponseCodec,
} from '../RPCClientCodec';

import {
  RPCError,
} from '../../error';

export interface ClientRequest {
  jsonrpc: string;
  method: string;
  params?: any[];
  id?: number;
}

export interface ClientResponse {
  jsonrpc: string;
  result?: any;
  error?: RPCError;
  id?: number;
}

export class RPCClientJSONCodec extends RPCClientCodec {
  public request(method: string, args: any[], id?: number): any {
    const req: ClientRequest = {
      jsonrpc: '2.0',
      method: method,
      params: args,
      id: id,
    };
    return JSON.stringify(req);
  }
  public response(res: any): RPCClientResponseCodec {
    const _res: ClientResponse = {
      id: res.id,
      jsonrpc: res.jsonrpc,
      result: res.result,
      error: res.error,
    };
    return new RPCClientJSONResponseCodec(_res);
  }
}

export class RPCClientJSONResponseCodec extends RPCClientResponseCodec {
  public constructor(private _res: ClientResponse) {
    super();
  }

  public id(): number | undefined {
    return this._res.id;
  }
  public error(): RPCError | undefined {
    return this._res.error;
  }
  public result(): any | undefined {
    return this._res.result;
  }
}
