import { Component, OnInit, Input, ViewChild, AfterContentInit } from '@angular/core';
import { MatTableDataSource, MatSort } from '@angular/material';
import { Router } from '@angular/router';
import { Store, select } from '@ngrx/store';
import { RPCError } from 'packages/core/rpc/error';
import { Notification } from '../../model';
import * as NotificationStore from '../../store/notification';
import { ReadAllByMemberSelector } from '../../store';
import { AuthSelector } from 'packages/member/store';
import { Member } from '../../../member/model';
import { PageParams } from 'app/commons/model';

@Component({
  selector: 'of-notification',
  templateUrl: './notification.component.html',
  styleUrls: ['./notification.component.scss']
})
export class NotificationComponent implements OnInit, AfterContentInit {

  notification$ = this.store.pipe(select(ReadAllByMemberSelector.select('notifications')));

  displayedColumns = ['id', 'title', 'message', 'member'];
  dataSource: MatTableDataSource<Notification>;
  @ViewChild(MatSort) sort: MatSort;

  constructor(
    private router: Router,
    private store: Store<NotificationStore.State>
  ) { }

  ngOnInit() {
    this.notification$.subscribe(
      (notifications: Notification[]) => {
        this.dataSource = new MatTableDataSource(notifications);
        this.dataSource.sort = this.sort;
      },
      (error: RPCError) => {
        console.log(error.message);
      }
    );
  }

  ngAfterContentInit() {
    // this.store.select(AuthSelector.select('member')).subscribe(
    //   (member: Member) => {
    //     const pageParams: PageParams = {
    //       pageNo: '1',
    //       countPerPage: '10',
    //     };
    //     this.store.dispatch(new NotificationStore.ReadAllByMember({member, pageParams}));
    //   },
    //   (error) => {
    //     console.log(error);
    //   }
    // );

  }

  handleRowClick(n: Notification) {
    this.router.navigate([n.url]);
  }

}
